@@ -1,7 +1,7 @@
 "use strict";
 
 var _ = require("lodash");
-var babel = require("babel-core");
+var babel = require("@babel/core");
 var colors = require("colors/safe");
 var jsdiff = require("diff");
 var Promise = require("bluebird");
@@ -47,4 +47,4 @@ module.exports = function (initial, expected, babelConfig) {
       throw new Error(generateErrorMessage(diff));
     }
   });
-};
\ No newline at end of file
+};
